#encoding: UTF-8 
=begin
/***************************************************************************
 *   ©2015-2021 Michael Uplawski <michael.uplawski@uplawski.eu>            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
=end


require 'optparse'
require 'optparse/time'
require 'ostruct'
require_relative 'logging'
require_relative 'version'

class ArgParser 
	include Logging

	# Returns a structure describing the options.
	#
	def self.parse(args)
		# The options specified on the command line will be collected in <b>options</b>.
		# We set default values here.
		options = OpenStruct.new
		options.fast = false 
		options.line = 0 
		options.file = nil

		op = OptionParser.new do |opts|
			opts.banner = "Usage:\t" << "%s -s [textfile] <options>" %($0) <<"\n"

			opts.separator ""
			opts.separator "Specific options:"

			opts.on('-' << "sFILE", '--' << "source FILE", "read this file") do |file|
				options.file = file
			end

			opts.on('-' << "f", '--' << "fast", "display at once entire lines") do |fast|
				options.fast = true
			end
			opts.on('-' << 'lLINE', '--' << "line LINE", "start reading file at line 'line'") do |line|
				options.line = line.to_i - 1
			end

			opts.separator ""
			opts.separator ("Common options") << ':'

			# No argument, shows at tail.  This will print an options summary.
			opts.on_tail(("-h"), ("--help"), ("Show this message") ) do
				puts opts
				exit true
			end

			opts.on_tail(("-v"), ("--version"), ("Show version and program information") ) do
				puts "\t#{APPNAME}, version #{VERSION} (called as #{$0})"
				puts "\t© 2015-#{YEAR} #{AUTHOR} #{AMAIL}>"
				exit true
			end
		end

		op.parse!(args)
		options
	end  # parse()

end  

